# pymacaron-google-datastore

An extension of pymacaron seamlessly adding API object (aka models)
serialisation to and from Google Firestore in Datastore mode.

See more at [pymacaron.com](http://pymacaron.com/db.html)

## Author

Erwan Lemonnier<br/>
[github.com/pymacaron](https://github.com/pymacaron)</br>
[github.com/erwan-lemonnier](https://github.com/erwan-lemonnier)<br/>
[www.linkedin.com/in/erwan-lemonnier/](https://www.linkedin.com/in/erwan-lemonnier/)